import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["as", "children", "fullWidth", "size", "design", "negative", "groupPositions", "onClick"];
import { Children, cloneElement } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Poly from '@s-ui/react-primitive-polymorphic-element';
import { atomButtonDesigns, atomButtonSizes } from '@s-ui/react-atom-button';
import { BASE_CLASS, isFunction } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";

var getGroupPosition = function getGroupPosition(_ref) {
  var groupPositions = _ref.groupPositions,
      numChildren = _ref.numChildren;
  return function (index) {
    if (index === 0) return groupPositions.FIRST;
    if (index === numChildren - 1) return groupPositions.LAST;
    return groupPositions.MIDDLE;
  };
};

var MoleculeButtonGroup = function MoleculeButtonGroup(_ref2) {
  var _ref2$as = _ref2.as,
      as = _ref2$as === void 0 ? 'div' : _ref2$as,
      children = _ref2.children,
      fullWidth = _ref2.fullWidth,
      sizeProp = _ref2.size,
      designProp = _ref2.design,
      negativeProp = _ref2.negative,
      groupPositions = _ref2.groupPositions,
      onClick = _ref2.onClick,
      props = _objectWithoutPropertiesLoose(_ref2, _excluded);

  var numChildren = children.length;
  var getGroupPositionByIndex = getGroupPosition({
    groupPositions: groupPositions,
    numChildren: numChildren
  });
  var extendedChildren = Children.toArray(children).filter(Boolean).map(function (child, index) {
    var _child$props = child.props,
        sizeChild = _child$props.size,
        designChild = _child$props.design,
        negativeChild = _child$props.negativeChild,
        onClickChild = _child$props.onClick;
    var groupPosition = getGroupPositionByIndex(index);

    var clickHandler = function clickHandler(event) {
      for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        args[_key - 1] = arguments[_key];
      }

      isFunction(onClickChild) && onClickChild.apply(void 0, [event].concat(args));
      isFunction(onClick) && onClick.apply(void 0, [event].concat(args));
    };

    return /*#__PURE__*/cloneElement(child, _extends({}, props, {
      negative: negativeChild || negativeProp,
      size: sizeChild || sizeProp,
      design: designChild || designProp,
      groupPosition: groupPosition,
      fullWidth: fullWidth,
      onClick: clickHandler
    }));
  });
  return /*#__PURE__*/_jsx(Poly, {
    className: cx(BASE_CLASS, fullWidth && BASE_CLASS + "--fullWidth"),
    children: extendedChildren
  });
};

MoleculeButtonGroup.displayName = 'MoleculeButtonGroup';
MoleculeButtonGroup.defaultProps = {
  groupPositions: {
    FIRST: 'first',
    MIDDLE: 'middle',
    LAST: 'last'
  }
};
export default MoleculeButtonGroup;
export { atomButtonDesigns as moleculeButtonGroupDesigns, atomButtonSizes as moleculeButtonGroupSizes };